pub struct CampaignsListResponse {
pub campaigns: Option<Vec<Campaign>>,
pub next_page_token: Option<String>,
pub kind: Option<String>,
}Expand description
Campaign List Response
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list campaigns (response)
Fields
campaigns: Option<Vec<Campaign>>Campaign collection.
next_page_token: Option<String>Pagination token to be used for the next list operation.
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “dfareporting#campaignsListResponse”.