pub struct ContentCategory {
pub kind: Option<String>,
pub account_id: Option<String>,
pub id: Option<String>,
pub name: Option<String>,
}Expand description
Organizes placements according to the contents of their associated webpages.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- patch content categories (request|response)
- insert content categories (request|response)
- update content categories (request|response)
- get content categories (response)
Fields
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “dfareporting#contentCategory”.
account_id: Option<String>Account ID of this content category. This is a read-only field that can be left blank.
id: Option<String>ID of this content category. This is a read-only, auto-generated field.
name: Option<String>Name of this content category. This is a required field and must be less than 256 characters long and unique among content categories of the same account.