pub struct CreativeCustomEvent {
pub target_type: Option<String>,
pub artwork_type: Option<String>,
pub video_reporting_id: Option<String>,
pub popup_window_properties: Option<PopupWindowProperties>,
pub artwork_label: Option<String>,
pub advertiser_custom_event_type: Option<String>,
pub exit_url: Option<String>,
pub id: Option<String>,
pub advertiser_custom_event_name: Option<String>,
}Expand description
Creative Custom Event.
This type is not used in any activity, and only used as part of another schema.
Fields
target_type: Option<String>Target type used by the event.
artwork_type: Option<String>Artwork type used by the creative.This is a read-only field.
video_reporting_id: Option<String>Video reporting ID, used to differentiate multiple videos in a single creative. This is a read-only field.
popup_window_properties: Option<PopupWindowProperties>Properties for rich media popup windows. This field is used only for exit events.
artwork_label: Option<String>Artwork label column, used to link events in DCM back to events in Studio. This is a required field and should not be modified after insertion.
advertiser_custom_event_type: Option<String>Type of the event. This is a read-only field.
exit_url: Option<String>Exit URL of the event. This field is used only for exit events.
id: Option<String>ID of this event. This is a required field and should not be modified after insertion.
advertiser_custom_event_name: Option<String>User-entered name for the event.