pub struct FloodlightActivitiesGenerateTagResponse {
pub kind: Option<String>,
pub floodlight_activity_tag: Option<String>,
}Expand description
Floodlight Activity GenerateTag Response
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- generatetag floodlight activities (response)
Fields
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “dfareporting#floodlightActivitiesGenerateTagResponse”.
floodlight_activity_tag: Option<String>Generated tag for this floodlight activity.