pub struct LandingPagesListResponse {
pub kind: Option<String>,
pub landing_pages: Option<Vec<LandingPage>>,
}Expand description
Landing Page List Response
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list landing pages (response)
Fields
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “dfareporting#landingPagesListResponse”.
landing_pages: Option<Vec<LandingPage>>Landing page collection