pub struct RegionsListResponse {
pub regions: Option<Vec<Region>>,
pub kind: Option<String>,
}Expand description
Region List Response
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list regions (response)
Fields
regions: Option<Vec<Region>>Region collection.
kind: Option<String>Identifies what kind of resource this is. Value: the fixed string “dfareporting#regionsListResponse”.