pub struct SiteSettings {
pub disable_brand_safe_ads: Option<bool>,
pub creative_settings: Option<CreativeSettings>,
pub active_view_opt_out: Option<bool>,
pub lookback_configuration: Option<LookbackConfiguration>,
pub disable_new_cookie: Option<bool>,
pub tag_setting: Option<TagSetting>,
}Expand description
Site Settings
This type is not used in any activity, and only used as part of another schema.
Fields
disable_brand_safe_ads: Option<bool>Whether brand safe ads are disabled for this site.
creative_settings: Option<CreativeSettings>Site-wide creative settings.
active_view_opt_out: Option<bool>Whether active view creatives are disabled for this site.
lookback_configuration: Option<LookbackConfiguration>Lookback window settings for this site.
Whether new cookies are disabled for this site.
tag_setting: Option<TagSetting>Configuration settings for dynamic and image floodlight tags.